@@ -1,6 +1,8 @@
-#![feature(backtrace)]
+#![cfg_attr(feature = "backtrace", feature(backtrace))]
 
 mod any_error_impl;
+#[cfg(feature = "backtrace")]
+mod bt;
 mod context;
 
 #[cfg(test)]
